@@ -589,7 +589,7 @@ int LsapiConn::processResp()
             ret = read(((char *)&m_respHeader) + sizeof(m_respHeader) -
                        m_iPacketHeaderLeft,
                        m_iPacketHeaderLeft);
-            LS_DBG_M(this, "Process packet header %d bytes", ret);
+            LS_DBG_M(this, "Process packet header %d bytes.", ret);
             if (ret > 0)
             {
                 m_iPacketHeaderLeft -= ret;
@@ -608,7 +608,7 @@ int LsapiConn::processResp()
 
                     }
                     else
-                        LS_DBG_M(getLogger(), "[%s] received %s, packetLen: %d",
+                        LS_DBG_M(getLogger(), "[%s] received %s, packetLen: %d.",
                                  getLogId(), s_packetName[m_respHeader.m_type],
                                  m_respHeader.m_packetLen.m_iLen);
 
@@ -888,7 +888,7 @@ int LsapiConn::readRespBody()
                 m_iPacketHeaderLeft = LSAPI_PACKET_HEADER_LEN;
                 if (ret > packetLen)
                 {
-                    LS_DBG_M(this, "Process packet header %d bytes",
+                    LS_DBG_M(this, "Process Packet header %d bytes",
                              ret - packetLen);
                     int len1 = processPacketHeader(pBuf + packetLen,
                                                    ret - packetLen);
@@ -994,7 +994,7 @@ int LsapiConn::readStderrStream()
         if (ret > 0)
         {
             int len, packetLen;
-            LS_DBG_M(this, "Process STDERR stream %d bytes, packet left: %d",
+            LS_DBG_M(this, "[LSAPI:STDERR]:Process STDERR stream %d bytes, packet left: %d",
                      ret, m_iPacketLeft);
             if (ret >= m_iPacketLeft)
             {
@@ -1029,7 +1029,7 @@ int LsapiConn::readStderrStream()
                 m_iPacketHeaderLeft = LSAPI_PACKET_HEADER_LEN;
                 if (ret > packetLen)
                 {
-                    LS_DBG_M(this, "Process packet header %d bytes",
+                    LS_DBG_M(this, "[LSAPI:STDERR]:Process Packet header %d bytes.",
                              ret - packetLen);
                     len = processPacketHeader(pBuf + packetLen, ret - packetLen);
                     if (len <= 0)
