@@ -63,6 +63,7 @@ class ProxyConn : public ExtConn
 
     int         readvSsl(const struct iovec *vector, const struct iovec *pEnd);
     void        setSSLAgain();
+    int         addForwardedFor(const char *pBegin);
 
 protected:
     virtual int doRead();
@@ -74,7 +75,7 @@ protected:
     virtual int onTimer();
 
     int read(char *pBuf , int size);
-    int readv(struct iovec *vector, size_t count);
+    int readv(struct iovec *vector, int count);
 
 public:
     virtual int removeRequest(ExtRequest *pReq);
