@@ -442,7 +442,7 @@ int ExtAppRegistry::configVhostOwnPhp(HttpVHost *pVHost)
 
             if (access(pCmd, X_OK) == -1)
             {
-                LS_ERROR(&currentCtx, "invalid path - %s, "
+                LS_ERROR(&currentCtx, "invalid path -- %s, "
                          "it cannot be started by Web server!", buf);
                 return -1;
             }
@@ -604,23 +604,15 @@ ExtWorker *ExtAppRegistry::configExtApp(const XmlNode *pNode, const HttpVHost *p
     
     iType -= HandlerType::HT_CGI;
     
-    /**
-     * AddApp first and then do the settings
-     */
-    int exist = 0;
-    pWorker = addApp(iType, pName, &exist);
-    if (!pWorker)
-    {
-        LS_ERROR(&currentCtx, "failed to add external processor: %s!", pName);
-        return NULL;
-    }
-    if (exist)
+    
+    pWorker = getApp(iType, pName);
+    if (pWorker)
     {
         LS_DBG(&currentCtx, "external processor %s exist, no need to addApp again!",
                 pName);
         return pWorker;
     }
-
+    
 
     pUri = ConfigCtx::getCurConfigCtx()->getExpandedTag(pNode, "address",
             achAddress, 128);
@@ -734,8 +726,13 @@ ExtWorker *ExtAppRegistry::configExtApp(const XmlNode *pNode, const HttpVHost *p
         }
     }
 
-
-
+    pWorker = addApp(iType, pName, NULL);
+    if (!pWorker)
+    {
+        LS_ERROR(&currentCtx, "failed to add external processor: %s!", pName);
+        return NULL;
+    }
+    
     pConfig = pWorker->getConfigPointer();
     assert(pConfig);
 
