@@ -23,13 +23,13 @@
 #include <spdy/h2connection.h>
 #include <spdy/spdyconnection.h>
 
-HioHandler *HioHandlerFactory::getHioHandler(HiosProtocol proto)
+HioHandler *HioHandlerFactory::getHandler(HiosProtocol proto)
 {
     HioHandler *pHioHandler;
     switch (proto)
     {
     case HIOS_PROTO_HTTP:
-        pHioHandler = HttpResourceManager::getInstance().getConnection();
+        pHioHandler = HttpResourceManager::getInstance().getHttpSession();
         return pHioHandler;
     case HIOS_PROTO_HTTP2:
         pHioHandler = H2Connection::get();
