@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -123,19 +123,12 @@ class NtwkIOLink::fp_list_list  *NtwkIOLink::s_pCur_fp_list_list =
         &NtwkIOLink::s_fp_list_list_normal;
 
 NtwkIOLink::NtwkIOLink()
-    : m_pVHostMap(NULL)
-    , m_iRemotePort(0)
-    , m_iInProcess(0)
-    , m_iPeerShutdown(0)
-    , m_tmToken(0)
-    , m_iSslLastWrite(0)
-    , m_iHeaderToSend(0)
-    , m_pFpList(NULL)
-    , m_sessionHooks()
-    , m_hasBufferedData(0)
+    : m_sessionHooks()
     , m_aioSFQ()
 {
+    m_hasBufferedData = 0;
     m_pModuleConfig = NULL;
+
 }
 
 
@@ -312,9 +305,6 @@ int NtwkIOLink::setLink(HttpListener *pListener,  int fd, ConnInfo *pInfo)
                     pInfo->m_pServerAddrInfo,
                     pInfo->m_remotePort);
     }
-    else
-        assert(pInfo); // Coverity claims that this must not be NULL!
-
     setConnInfo(pInfo);
     setState(HIOS_CONNECTED);
     setHandler(NULL);
@@ -387,7 +377,8 @@ void NtwkIOLink::tryRead()
 int NtwkIOLink::handleEvents(short evt)
 {
     int event = evt;
-    LS_DBG_M(this, "NtwkIOLink::handleEvents() events=%d!", event);
+    LS_DBG_M(this, "NtwkIOLink::handleEvents() fd: %d, mask=%hd, events=%hd!",
+             getfd(), getEvents(), evt);
     if (getState() == HIOS_SHUTDOWN)
     {
         if (event & (POLLHUP | POLLERR))
@@ -407,7 +398,16 @@ int NtwkIOLink::handleEvents(short evt)
     }
     m_iInProcess = 1;
     if (event & POLLIN)
+    {
+        //NOTE: force to allow flush output if unexpected POLLIN happens,
+        //      flush could detect socket need to be closed.
+        if ((getEvents() & POLLIN) == 0)
+        {
+            setAllowWrite();
+            setFlag(HIO_FLAG_PAUSE_WRITE, 0);
+        }
         (*m_pFpList->m_onRead_fp)(this);
+    }
     if (event & (POLLHUP | POLLERR))
     {
         m_iInProcess = 0;
@@ -790,10 +790,8 @@ int NtwkIOLink::onWriteSSL(NtwkIOLink *pThis)
     }
     int ret = 0;
     if (pThis->m_ssl.isConnected())
-    {
         ret = pThis->doWrite();
-        pThis->flushSslWpending();
-    }
+    pThis->flushSslWpending();
     return ret;
 }
 
@@ -810,10 +808,8 @@ int NtwkIOLink::onReadSSL(NtwkIOLink *pThis)
     }
     int ret = 0;
     if (pThis->m_ssl.isConnected())
-    {
         ret = pThis->doRead();
-        pThis->flushSslWpending();
-    }
+    pThis->flushSslWpending();
     return ret;
 }
 
@@ -993,7 +989,9 @@ int NtwkIOLink::onTimer()
 
         if (detectClose())
             return 0;
+        m_iInProcess = 1;
         (*m_pFpList->m_onTimer_fp)(this);
+        m_iInProcess = 0;
         if (getState() == HIOS_CLOSING)
         {
             if (flushSslWpending() != 0)
@@ -1513,10 +1511,8 @@ int NtwkIOLink::onReadSSL_T(NtwkIOLink *pThis)
     }
     int ret = 0;
     if (pThis->m_ssl.isConnected())
-    {
         ret = pThis->doRead();
-        pThis->flushSslWpending();
-    }
+    pThis->flushSslWpending();
     return ret;
 }
 
@@ -1543,7 +1539,10 @@ int NtwkIOLink::onWriteSSL_T(NtwkIOLink *pThis)
         return ret;
     }
     else
+    {
+        pThis->flushSslWpending();
         MultiplexerFactory::getMultiplexer()->suspendWrite(pThis);
+    }
     return 0;
 }
 
@@ -1719,7 +1718,7 @@ int NtwkIOLink::sslSetupHandler()
     }
     int ret = setupHandler((HiosProtocol)spdyVer);
     if (!m_iInProcess && isWantRead() && m_ssl.hasPendingIn())
-        handleEvents(POLLIN);
+        (*m_pFpList->m_onRead_fp)(this);
     return ret;
 }
 
