@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -81,7 +81,7 @@
 /***
  * Do not change the below format, it will be set correctly while packing the code
  */
-#define BUILDTIME  " (built: Fri Jan 24 16:42:37 UTC 2020)"
+#define BUILDTIME  " (built: Wed Jan 29 20:56:17 UTC 2020)"
 
 #define GlobalServerSessionHooks (LsiApiHooks::getServerSessionHooks())
 
@@ -93,7 +93,6 @@ static int s_iCpuCount = 1;
 LshttpdMain::LshttpdMain()
     : m_pServer(NULL)
     , m_pBuilder(NULL)
-    , m_pid(0)
     , m_noDaemon(0)
     , m_noCrashGuard(0)
     , m_iConfTestMode(0)
@@ -405,7 +404,7 @@ int LshttpdMain::getFullPath(const char *pRelativePath, char *pBuf,
 int LshttpdMain::execute(const char *pExecCmd, const char *pParam)
 {
     char achBuf[512];
-    int n = getFullPath(pExecCmd, achBuf, 511);
+    int n = getFullPath(pExecCmd, achBuf, 512);
     ls_snprintf(&achBuf[n], 511 - n, " %s", pParam);
     int ret = system(achBuf);
     return ret;
@@ -439,8 +438,7 @@ int LshttpdMain::startAdminSocket()
     }
     if (i == 100)
         return LS_FAIL;
-    if (m_fdAdmin != -1)
-        ::fcntl(m_fdAdmin, F_SETFD, FD_CLOEXEC);
+    ::fcntl(m_fdAdmin, F_SETFD, FD_CLOEXEC);
     HttpServerConfig::getInstance().setAdminSock(strdup(achBuf));
     LS_NOTICE("[ADMIN] server socket: %s", achBuf);
     return 0;
@@ -455,11 +453,7 @@ int LshttpdMain::closeAdminSocket()
         if (strncmp(pAdminSock, "uds://", 6) == 0)
             unlink(&pAdminSock[5]);
     }
-    if (m_fdAdmin != -1)
-    {
-        close(m_fdAdmin);
-        m_fdAdmin = -1;
-    }
+    close(m_fdAdmin);
     return 0;
 }
 
@@ -469,8 +463,6 @@ int LshttpdMain::acceptAdminSockConn()
     struct sockaddr_in peer;
     socklen_t addrlen;
     addrlen = sizeof(peer);
-    if (m_fdAdmin == -1)
-        return LS_FAIL;
     int fd = accept(m_fdAdmin, (struct sockaddr *)&peer, &addrlen);
     if (fd == -1)
         return LS_FAIL;
@@ -574,7 +566,7 @@ int LshttpdMain::testServerRoot(const char *pRoot)
             return LS_FAIL;
     }
 #else
-    lstrncpy(achBuf, pRoot, sizeof(achBuf));
+    strcpy(achBuf, pRoot);
 #endif
 
     int len = strlen(pRoot);
@@ -598,12 +590,12 @@ int LshttpdMain::getServerRootFromExecutablePath(const char *command,
     if (*command != '/')
     {
         getcwd(achBuf, left_len - 1);
-        lstrncat(achBuf, "/", sizeof(achBuf));
+        strcat(achBuf, "/");
         left_len -= strlen(achBuf);
     }
 
     if (left_len >= (int)strlen(command))
-        lstrncat(achBuf, command, sizeof(achBuf));
+        strcat(achBuf, command);
     else
     {
         printf("Warn: Command too long, bypass it.");
@@ -611,10 +603,8 @@ int LshttpdMain::getServerRootFromExecutablePath(const char *command,
 
     char *p = strrchr(achBuf, '/');
     if (p)
-    {
         *(p + 1) = 0;
-        lstrncat(p, "../", sizeof(achBuf) - (p - achBuf));
-    }
+    strcat(p, "../");
     GPath::clean(achBuf);
     memccpy(pBuf, achBuf, 0, len);
     return 0;
@@ -646,10 +636,10 @@ int LshttpdMain::guessCommonServerRoot()
     {
         if (!pServerRoots[i])
             continue;
-        lstrncpy(achBuf, pServerRoots[i], sizeof(achBuf));
+        strcpy(achBuf, pServerRoots[i]);
         for (size_t j = 0; j < sizeof(pServerDirs) / sizeof(char *); ++j)
         {
-            lstrncat(achBuf, pServerDirs[j], sizeof(achBuf));
+            strcat(achBuf, pServerDirs[j]);
             if (testServerRoot(achBuf) == 0)
                 return 0;
         }
@@ -1053,6 +1043,8 @@ int LshttpdMain::init(int argc, char *argv[])
         GlobalServerSessionHooks->runCallbackNoParam(LSI_HKPT_WORKER_INIT,
                 NULL);
 
+
+
     return 0;
 }
 
@@ -1252,11 +1244,7 @@ void LshttpdMain::onNewChildStart(ChildProc * pProc)
     {
         HttpServerConfig::getInstance().setUseSendfile(1);
     }
-    if (m_fdAdmin != -1)
-    {
-        close(m_fdAdmin);
-        m_fdAdmin = -1;
-    }
+    close(m_fdAdmin);
 
 #ifdef IS_LSCPD
     snprintf(argv0, 80, "lscpd (lscpd - #%02d)", pProc->m_iProcNo);
@@ -1499,11 +1487,7 @@ void LshttpdMain::applyChanges()
 void LshttpdMain::gracefulRestart()
 {
     LS_DBG_L("Graceful Restart... ");
-    if (m_fdAdmin != -1)
-    {
-        close(m_fdAdmin);
-        m_fdAdmin = -1;
-    }
+    close(m_fdAdmin);
     broadcastSig(SIGTERM, 1);
     s_tmDelayShutdown = 0;
     s_iRunning = 0;
@@ -1821,17 +1805,81 @@ static long getProcessStartTime(int pid)
 
 
 #if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
+
+static long s_boot_time = 0;
+static long s_jiffies_per_sec = 100;
+static long getBootTime()
+{
+    if (s_boot_time)
+        return s_boot_time;
+    s_jiffies_per_sec = sysconf(_SC_CLK_TCK);
+    char stat_buf[4096];
+    int fd = open("/proc/stat",O_RDONLY);
+
+    if (fd < 0)
+        return -1;
+
+    int ret = read(fd, stat_buf, sizeof(stat_buf));
+
+    close(fd);
+
+    if (ret < 0)
+        return -1;
+
+    char *p = strstr(stat_buf, "btime ");
+    if (!p)
+        return -1;
+    p += 6;
+
+    sscanf(p,"%lu", &s_boot_time);
+    return s_boot_time;
+}
+
+
+static long getProcessStartTimeSinceBoot(int pid)
+{
+    char stat_buf[4096];
+    char proc_pid_path[80];
+    snprintf(proc_pid_path, sizeof(proc_pid_path), "/proc/%d/stat", pid);
+    int fd = open(proc_pid_path ,O_RDONLY);
+
+    if(fd < 0)
+        return -1;
+
+    int ret = read(fd, stat_buf, sizeof(stat_buf));
+    close(fd);
+
+    if(ret < 0)
+        return -1;
+
+    char *p = (char *)memchr(stat_buf, ')', ret);
+    if (!p)
+        return -1;
+    char *end = p + ret;
+    p += 2;
+    int i;
+    for(i = 0; i < 19; ++i)
+    {
+        p = (char *)memchr(p, ' ', end - p);
+        if (!p)
+            return -1;
+        ++p;
+    }
+    long diff = strtol(p, NULL, 10);
+    return diff;
+}
+
+
 static long getProcessStartTime(int pid)
 {
-    char proc_pid_path[80];
-    struct stat st;
-    snprintf(proc_pid_path, sizeof(proc_pid_path), "/proc/%d/stat", pid);
-    int ret = stat(proc_pid_path, &st);
-    if (ret == -1)
-    {
+    long diff = getProcessStartTimeSinceBoot(pid);
+    if (diff == -1)
         return -1;
-    }
-    return st.st_ctime;
+    long boot_time = getBootTime();
+    if (boot_time == -1)
+        return -1;
+    long real = boot_time + diff / s_jiffies_per_sec;
+    return real;
 }
 #endif
 
