@@ -132,7 +132,8 @@ static void *ParseConfig(module_param_info_t *param, int param_count,
     msc_conf_t *pConfig = new msc_conf_t;
 
     g_api->log(NULL, LSI_LOG_DEBUG,  "[Module:%s] ParseConfig entry, "
-                "level %d\n", ModuleNameStr, level);
+                "level %d, Mod_Security v%s.%s.%s\n", ModuleNameStr, level,
+                MODSECURITY_MAJOR, MODSECURITY_MINOR, MODSECURITY_PATCHLEVEL);
     if (!pConfig)
         return NULL;
 
@@ -451,8 +452,8 @@ static int UriMapHook(lsi_param_t *rec)
     g_api->get_req_org_uri(session, uri, uriLen + 1);
     if (qs_len > 0)
     {
-        strcat(uri, "?");
-        strncat(uri, qs, qs_len);
+        *(uri + uriLen) = '?';
+        lstrncpy(uri + uriLen + 1, qs, qs_len + 1);
     }
     char httpMethod[10] = {0};
     g_api->get_req_var_by_id(session, LSI_VAR_REQ_METHOD, httpMethod, 10);
