@@ -576,6 +576,9 @@ int VMemBuf::setFd(const char *pFileName, int fd)
 
 void VMemBuf::rewindReadWriteBuf()
 {
+    if (m_bufList.empty())
+        return ;
+    
 #ifdef _RELEASE_MMAP
     if (m_iType == VMBUF_FILE_MAP)
     {
@@ -638,6 +641,9 @@ void VMemBuf::rewindWriteBuf()
 
 void VMemBuf::rewindReadBuf()
 {
+    if (m_bufList.empty())
+        return ;
+    
 #ifdef _RELEASE_MMAP
     if (m_iType == VMBUF_FILE_MAP)
     {
@@ -653,12 +659,9 @@ void VMemBuf::rewindReadBuf()
     }
 #endif
     ls_atomic_spin_lock(&m_lock);
-    if (!m_bufList.empty())
-    {
-        m_pCurRBlock = m_bufList.begin();
-        m_curRBlkPos = (*m_pCurRBlock)->getBlockSize();
-        m_pCurRPos = (*m_pCurRBlock)->getBuf();
-    }
+    m_pCurRBlock = m_bufList.begin();
+    m_curRBlkPos = (*m_pCurRBlock)->getBlockSize();
+    m_pCurRPos = (*m_pCurRBlock)->getBuf();
     ls_atomic_spin_unlock(&m_lock);
 }
 
